from __future__ import absolute_import

from sctokenizer.cpp_tokenizer import CppTokenizer
from sctokenizer.assets.c_keywords import c_keyword_set
from sctokenizer.assets.c_operators import c_operator_set
from sctokenizer.token import TokenType, Token

class CTokenizer(CppTokenizer):
    def __init__(self):
        super().__init__()
        self.keyword_set = c_keyword_set
        self.operator_set = c_operator_set




from __future__ import absolute_import 

from .tokenizer import Tokenizer
from .cpp_tokenizer import CppTokenizer
from .php_tokenizer import PhpTokenizer
from .source import Source
from .main import tokenize_file, tokenize_str
from .token import Token, TokenType
from .python_tokenizer import PythonTokenizer
from .java_tokenizer import JavaTokenizer
from .c_tokenizer import CTokenizer



from __future__ import absolute_import
import enum
from sctokenizer.token import TokenType, Token

class TokenizerState(enum.Enum):
    REGULAR = 0
    IN_STRING = 1
    IN_CHAR = 2
    IN_COMMENT = 3
    IN_LINECOMMENT = 4
    IN_MACRO = 5
    # IN_OPERATOR = 6
    IN_NUMBER = 7
    IN_INCLUDE = 8
    IN_INCLUDE_HEADER = 9

class Tokenizer():
    def __init__(self):
        self.keyword_set = None
        self.operator_set = None
        self.linenumber = 1
        self.colnumber = 1

    def tokenize(self):
        pass

    def add_pending(self, tokens, pending, token_type, len_lines, t):
        if pending <= ' ':
            return
        for k in range(t):
            self.colnumber -= (len_lines[k] + 1)
        
        if pending in self.operator_set:
            tokens.append(Token(pending, TokenType.OPERATOR, self.linenumber, self.colnumber + 1))
        elif pending in self.keyword_set:
            tokens.append(Token(pending, TokenType.KEYWORD, self.linenumber, self.colnumber + 1))
        else:
            tokens.append(Token(pending, token_type, self.linenumber, self.colnumber + 1))

    def is_alpha(self, cur):
        return (cur >= 'a' and cur <= 'z') or \
                (cur >= 'A' and cur <= 'Z') or \
                cur == '_' or ord(cur) > 127

    def is_identifier(self, str, allow_symbols=['_']):
        temp = str
        for symbol in allow_symbols:
            temp = temp.replace(symbol, '')
        return temp.isalnum()


    


php_keyword_set = {
    'abstract',
    'array',
    'as',
    'break',
    'callable',
    'case',
    'catch',
    'class',
    'clone',
    'const',
    'continue',
    'declare',
    'default',
    'die',
    'do',
    'echo',
    'else',
    'elseif',
    'empty',
    'enddeclare',
    'endfor',
    'endforeach',
    'endif',
    'endswitch',
    'eval',
    'exit',
    'extends',
    'final',
    'finally',
    'fn',
    'for',
    'foreach',
    'function',
    'global',
    'goto',
    'if',
    'implements',
    'include',
    'include_one',
    'instanceof',
    'interface',
    'isset',
    'list',
    'namesapce',
    'new',
    'print',
    'private',
    'protected',
    'public',
    'require',
    'require_one',
    'return',
    'static',
    'switch',
    'throw',
    'trait',
    'try',
    'unset',
    'use',
    'var',
    'while',
    'yield',
    'yield from'
}


from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

PROJECT_URLS = {
    'Bug Tracker': 'https://github.com/ngocjr7/sctokenizer/issues',
    'Documentation': 'https://github.com/ngocjr7/sctokenizer/blob/master/README.md',
    'Source Code': 'https://github.com/ngocjr7/sctokenizer'
}

setup(name='sctokenizer',
      description='A Source Code Tokenizer',
      author='Ngoc Bui',
      long_description=long_description,
      long_description_content_type="text/markdown",
      project_urls=PROJECT_URLS,
      author_email='ngocjr7@gmail.com',
      version='0.0.8',
      packages=find_packages(),
      python_requires='>=3.6')



python_keyword_set = {
    'and',
    'as',
    'assert',
    'async',
    'await',
    'break',
    'class',
    'continue',
    'def',
    'del',
    'elif',
    'else',
    'except',
    'False',
    'finally',
    'for',
    'from',
    'global',
    'if',
    'import',
    'in',
    'is',
    'lambda',
    'None',
    'nonlocal',
    'not',
    'or',
    'pass',
    'raise',
    'return',
    'True',
    'try',
    'while',
    'with',
    'yield'
}